from captcha.fields import ReCaptchaField
from django.contrib.auth.forms import UserCreationForm
from django.contrib.auth.models import User


class UserSignupForm(UserCreationForm):
    recaptcha = ReCaptchaField()

    class Meta:
        model = User
        fields = ('username', 'email', 'password1', 'password2', 'recaptcha',)



from django import template

register = template.Library()


@register.inclusion_tag("karvi/addons/alerts.html")
def karvi_alert(message, type=None, title=None, dismissible=False):
    if not type:
        type = ""
    return {"message": message, "type": type, "title": title, "dismissible": dismissible}



from unittest import TestCase
from karvi.utils.path import Path


class TestPath(TestCase):
    def test_equals(self):
        p = Path(__file__)
        q = Path(__file__)
        self.assertEqual(p, q)



name = "karvi"
__version__ = "0.4.0"


def get_templates_dir():
    import os

    templates_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "templates/")
    return templates_dir


def get_version():
    return __version__



from django import template
from django.conf import settings

register = template.Library()


@register.simple_tag()
def karvi_settings(value):
    if value == "sitename":
        return settings.KARVI_SITENAME
    if value == "homepage":
        return settings.KARVI_HOMEPAGE
    if value == "version":
        return settings.KARVI_VERSION
    pass



from django.conf import settings
from django.contrib.auth import login, authenticate
from django.shortcuts import redirect
from django.views.generic import TemplateView, FormView

from .forms import UserSignupForm


class IndexView(TemplateView):
    template_name = 'karvi/index.html'


class UserCreationView(FormView):
    form_class = UserSignupForm
    template_name = 'registration/signup.html'

    def form_valid(self, form):
        form.save()
        username = form.cleaned_data.get('username')
        password = form.cleaned_data.get('password1')
        user = authenticate(username=username, password=password)
        login(self.request, user)
        return redirect(settings.SIGNUP_REDIRECT_URL)



from django.urls import path, include

from .views import UserCreationView

urlpatterns = [
    path("accounts/", include("django.contrib.auth.urls")),
    path("accounts/signup", UserCreationView.as_view(), name="signup"),
]



from django.forms import widgets


class SelectEx(widgets.Select):
    searchable = False
    multiple = False
    select_class = "selectex"
    searchable_class = "is-searchable"
    multiple_class = "is-multiple"

    def __init__(self, attrs=None):
        if attrs is not None:
            self.multiple = attrs.pop("multiple", self.multiple)
            self.searchable = attrs.pop("searchable", self.searchable)
        return super().__init__(attrs)

    def build_attrs(self, base_attrs, extra_attrs=None):
        attrs = super().build_attrs(base_attrs, extra_attrs)
        klass = self.select_class
        if self.multiple:
            klass = "{} {}".format(klass, self.multiple_class)
        if self.searchable:
            klass = "{} {}".format(klass, self.searchable_class)
        attrs["class"] = klass
        return attrs



from os.path import isfile, isdir, abspath, join, dirname, exists
from os import PathLike


class Path(PathLike):
    def __init__(self, path):
        self.__path = path

    def is_file(self):
        return isfile(self.__path)

    def is_dir(self):
        return isdir(self.__path)

    def dirname(self):
        if self.is_dir:
            return self.__path
        else:
            return dirname(self.__path)

    def join(self, path):
        newpath = abspath(join(self.__path, path))
        np = Path(newpath)
        if np.exists():
            return np
        else:
            raise Exception('Path "{}" doesn\'t exists'.format(newpath))

    def back(self, count=1):
        newpath = self
        if count >= 1:
            for i in range(count):
                try:
                    newpath = newpath.join("..")
                except Exception as e:
                    raise e
            return newpath
        else:
            pass

    def exists(self):
        return exists(self.__path)

    def __str__(self):
        return self.__path

    def __fspath__(self):
        return self.__str__()

    def __unicode__(self):
        return self.__str__()

    def __eq__(self, other):
        return self.__path == other.__path

    def __neq__(self, other):
        return not self.__eq__(other)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['karvi',
 'karvi.migrations',
 'karvi.templatetags',
 'karvi.tests',
 'karvi.tests.utils',
 'karvi.utils',
 'karvi.widgets']

package_data = \
{'': ['*'],
 'karvi': ['assets/*',
           'assets/js/*',
           'assets/js/plugins/*',
           'assets/sass/*',
           'assets/ts/*',
           'assets/ts/utils/*',
           'static/karvi/css/*',
           'static/karvi/js/*',
           'templates/karvi/addons/*',
           'templates/karvi/base/*',
           'templates/karvi/navbar/*',
           'templates/registration/*']}

install_requires = \
['django>=2.2,<2.3']

setup_kwargs = {
    'name': 'karvi',
    'version': '0.4.0',
    'description': 'A small package with custom resources for Django projects.',
    'long_description': '# Karvi\n\nA small package with some custom templates and scripts for Django projects.\n\n## Requirements\n\n-   [Python](https://www.python.org) 3.6\n-   [Django](https://www.djangoproject.com) 2.2\n\n## Projects in use\n\n-   [Bulma](https://bulma.io) 0.9\n-   [TypeScript](https://www.typescriptlang.org) 3.2\n-   [Laravel Mix](https://github.com/JeffreyWay/laravel-mix) 4.0\n-   [Yarn](https://yarnpkg.com)\n-   [Poetry](https://python-poetry.org)\n',
    'author': 'Facundo Arano',
    'author_email': 'aranofacundo@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.com/aranofacundo/karvi',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



from django import template, forms

register = template.Library()


@register.simple_tag(takes_context=True)
def pagination_pagelink(context, value):
    request = context["request"]
    r = request.GET.copy()
    r["page"] = str(value)
    urlencode = r.urlencode()
    return urlencode


@register.filter()
def form_styling(field):
    def styling(field, klass):
        field.field.widget.attrs.update({"class": klass})
        return field

    widget = field.field.widget
    input_type = (forms.TextInput, forms.PasswordInput, forms.EmailInput, forms.NumberInput)
    textarea_type = (forms.Textarea,)
    if isinstance(widget, input_type):
        return styling(field, "input")
    elif isinstance(widget, textarea_type):
        return styling(field, "textarea")

    return field



import toml
from os import getenv
from karvi.utils.path import Path


class Settings:
    def __init__(self, path=None, mode=None):
        if path:
            if isinstance(path, Path):
                self.__path = path
            elif isinstance(path, str):
                self.__path = Path(path)
            else:
                raise Exception("Parameter 'path' must be a 'String' or 'Path'")

            self.__settings = toml.load(str(self.__path))

    def get(self, key, default=None):
        env = getenv(key, default)
        toml = self.__settings.get(key, default)
        if env:
            return env
        return toml
